@@ -285,7 +285,8 @@ read_twix <- function(fname, verbose, full_fid = FALSE,
   # get the resolution and geom info
   paras <- calc_siemens_paras(vars, FALSE)
   
-  meta <- list(EchoTime = vars$te)
+  meta <- list(EchoTime = vars$te, RepetitionTime = vars$tr,
+               FlipAngle = vars$flip_ang)
 
   mrs_data <- mrs_data(data = data, ft = vars$ft, resolution = paras$res,
                        ref = paras$ref, nuc = paras$nuc,
@@ -308,13 +309,19 @@ read_twix <- function(fname, verbose, full_fid = FALSE,
   }
   
   # correct the voxel dimensions for MRSI
+  # this is needed because the Siemens software automatically zero-pads k-space
+  # to a power of two, but we don't want this when dealing with raw twix data
   x_pts <- max(mrs_data$twix_inds$Seg) + 1
   y_pts <- max(mrs_data$twix_inds$Lin) + 1
   
-  if (x_pts > 1 || y_pts > 1) {
-    mrs_data$resolution[2] <- vars$x_dim / x_pts
-    mrs_data$resolution[3] <- vars$y_dim / y_pts
-  }
+if (x_pts > 1 || y_pts > 1) {
+  mrs_data$resolution[2] <- vars$x_dim / x_pts
+  mrs_data$resolution[3] <- vars$y_dim / y_pts
+  
+  # fix the affine
+  mrs_data$affine[,1] <- mrs_data$affine[,1] * vars$x_pts / x_pts
+  mrs_data$affine[,2] <- mrs_data$affine[,2] * vars$y_pts / y_pts
+}
   
   return(mrs_data)
 }
@@ -412,6 +419,10 @@ read_siemens_txt_hdr <- function(input, version = "vd", verbose) {
       vars$ft <- as.numeric(strsplit(line, "=")[[1]][2])
     } else if (startsWith(line, "alTE[0]")) {
       vars$te <- (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
+    } else if (startsWith(line, "alTR[0]")) {
+      vars$tr <- (as.numeric(strsplit(line, "=")[[1]][2])) / 1e6
+    } else if (startsWith(line, "adFlipAngleDegree[0]")) {
+      vars$flip_ang <- (as.numeric(strsplit(line, "=")[[1]][2]))
     } else if (startsWith(line, "sSpecPara.lVectorSize")) {
       vars$N <- as.integer(strsplit(line, "=")[[1]][2])
     } else if (startsWith(line, "sSpecPara.lFinalMatrixSizePhase")) {
